@@ -7,4 +7,5 @@ from .optics import *
 from .scatterers import *
 from .sequences import *
 
-from . import image, losses, generators, models, utils, layers, backend
\ No newline at end of file
+
+from . import image, losses, generators, models, utils, layers, backend, test
\ No newline at end of file
