@@ -234,13 +234,9 @@ class FlipLR(Augmentation):
         if number_of_updates % 2:
             for prop in image.properties:
                 if "position" in prop:
-                    position = prop["position"]
-                    new_position = (
-                        position[0],
-                        image.shape[1] - position[1] - 1,
-                        *position[2:],
-                    )
-                    prop["position"] = new_position
+                    position = np.array(prop["position"])
+                    position[..., 1] = image.shape[1] - position[..., 1]
+                    prop["position"] = position
 
 
 class FlipUD(Augmentation):
@@ -261,12 +257,9 @@ class FlipUD(Augmentation):
         if number_of_updates % 2:
             for prop in image.properties:
                 if "position" in prop:
-                    position = prop["position"]
-                    new_position = (
-                        image.shape[0] - position[0] - 1,
-                        *position[1:],
-                    )
-                    prop["position"] = new_position
+                    position = np.array(prop["position"])
+                    position[..., 0] = image.shape[1] - position[..., 0]
+                    prop["position"] = position
 
 
 class FlipDiagonal(Augmentation):
@@ -287,9 +280,11 @@ class FlipDiagonal(Augmentation):
         if number_of_updates % 2:
             for prop in image.properties:
                 if "position" in prop:
-                    position = prop["position"]
-                    new_position = (position[1], position[0], *position[2:])
-                    prop["position"] = new_position
+                    position = np.array(prop["position"])
+                    t = np.array(position[..., 0])
+                    position[..., 0] = position[..., 1]
+                    position[..., 1] = t
+                    prop["position"] = position
 
 
 class Affine(Augmentation):
@@ -450,18 +445,21 @@ class Affine(Augmentation):
         for prop in image.properties:
             if "position" in prop:
                 position = np.array(prop["position"])
-                prop["position"] = np.array(
-                    (
-                        *(
-                            (
-                                inverse_mapping
-                                @ (position[:2] - center + np.array([dy, dx]))
-                                + center
-                            )
-                        ),
-                        *position[3:],
+
+                inverted = (
+                    np.dot(
+                        inverse_mapping,
+                        (position[..., :2] - center + np.array([dy, dx]))[
+                            ..., np.newaxis
+                        ],
                     )
-                )
+                    .squeeze()
+                    .transpose()
+                ) + center
+
+                position[..., :2] = inverted
+
+                prop["position"] = position
 
         return image
 
@@ -608,7 +606,7 @@ class Crop(Augmentation):
         Can also be a function that returns any of the other types.
     crop_mode : str {"retain", "remove"}
         How the `crop` argument is interpreted. If "remove", then
-        `crop` denotes the amount to crop from the edges. If "retain", 
+        `crop` denotes the amount to crop from the edges. If "retain",
         `crop` denotes the size of the output.
     corner : tuple of ints or Callable[Image]->tuple of ints or "random"
         Top left corner of the cropped region. Can be a tuple of ints,
@@ -679,7 +677,7 @@ class Crop(Augmentation):
             if "position" in prop:
                 position = np.array(prop["position"])
                 try:
-                    position[0:2] -= np.array(slice_start)[0:2]
+                    position[..., 0:2] -= np.array(slice_start)[0:2]
                     prop["position"] = position
                 except IndexError:
                     pass
